==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/StartChannelRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class StartChannelRequest(channelName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.StartChannelRequest = {
    import StartChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.StartChannelRequest
      .builder()
      .channelName(__string.unwrap(channelName): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.StartChannelRequest.ReadOnly =
    zio.aws.mediatailor.model.StartChannelRequest.wrap(buildAwsValue())
}
object StartChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.StartChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.StartChannelRequest =
      zio.aws.mediatailor.model.StartChannelRequest(channelName)
    def channelName: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.StartChannelRequest
  ) extends zio.aws.mediatailor.model.StartChannelRequest.ReadOnly {
    override val channelName: __string =
      zio.aws.mediatailor.model.primitives.__string(impl.channelName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.StartChannelRequest
  ): zio.aws.mediatailor.model.StartChannelRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.295.4-sources.jar: zio/aws/mediatailor/model/StartChannelRequest.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class StartChannelRequest(channelName: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.StartChannelRequest = {
    import StartChannelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.StartChannelRequest
      .builder()
      .channelName(channelName: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.StartChannelRequest.ReadOnly =
    zio.aws.mediatailor.model.StartChannelRequest.wrap(buildAwsValue())
}
object StartChannelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.StartChannelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.StartChannelRequest =
      zio.aws.mediatailor.model.StartChannelRequest(channelName)
    def channelName: __string
    def getChannelName: ZIO[Any, Nothing, __string] = ZIO.succeed(channelName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.StartChannelRequest
  ) extends zio.aws.mediatailor.model.StartChannelRequest.ReadOnly {
    override val channelName: __string = impl.channelName(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.StartChannelRequest
  ): zio.aws.mediatailor.model.StartChannelRequest.ReadOnly = new Wrapper(impl)
}
